@@ -83,6 +83,7 @@ class Dialog(Async):
     _ACTIVE_INSTANCES = []
 
     def __init__(self, dialog):
+        super(Dialog, self).__init__()
         self._dialog = dialog
         self._dialog.connect("response", self._result_handler)
         self._dialog.show()
@@ -121,6 +122,7 @@ class PasswordDialog(Dialog):
         label = builder.get_object('message')
         label.set_label(message)
         self.dialog.set_title(title)
+        self.dialog.set_keep_above(True)
         self.dialog.show_all()
         super(PasswordDialog, self).__init__(self.dialog)
 
