@@ -8,7 +8,7 @@ from __future__ import unicode_literals
 from gi.repository import Gio
 from gi.repository import Gtk
 
-from .async_ import Async, Coroutine, Return
+from .async_ import Async, Coroutine
 from .common import setdefault, DaemonBase
 from .compat import basestring
 from .locale import _
@@ -146,7 +146,7 @@ class UdiskieMenu(object):
         self._quit_action = daemon.mainloop.quit
         self.flat = flat
 
-    def __call__(self, menu, extended):
+    def __call__(self, menu, extended=True):
         """
         Populate the menu with udiskie mount operations.
 
