@@ -23,9 +23,8 @@ import os.path
 from gi.repository import GLib
 
 from .async_ import AsyncList, Coroutine, Return
-from .common import Emitter, samefile, AttrDictView, wraps, NullDevice
-from .compat import fix_str_conversions
-from .dbus import connect_service, MethodsProxy
+from .common import Emitter, AttrDictView, wraps, NullDevice, BaseDevice
+from .dbus import connect_service, MethodsProxy, DBusCall
 from .locale import _
 
 
@@ -39,8 +38,7 @@ def filter_opt(opt):
     return [k for k, v in opt.items() if v]
 
 
-@fix_str_conversions
-class Device(object):
+class Device(BaseDevice):
 
     """Helper base class for devices."""
 
@@ -57,24 +55,6 @@ class Device(object):
         self._P = property_proxy
         self._M = method_proxy
 
-    def __str__(self):
-        """Display as object path."""
-        return self.object_path
-
-    def __eq__(self, other):
-        """Comparison by object path."""
-        return self.object_path == str(other)
-
-    def __ne__(self, other):
-        """Comparison by object path."""
-        return not (self == other)
-
-    def is_file(self, path):
-        """Comparison by mount and device file path."""
-        return (samefile(path, self.device_file) or
-                samefile(path, self.loop_file) or
-                any(samefile(path, mp) for mp in self.mount_paths))
-
     # availability of interfaces
     @property
     def is_drive(self):
@@ -137,6 +117,16 @@ class Device(object):
         """Check if there is media available in the drive."""
         return self._P.DeviceIsMediaAvailable
 
+    @property
+    def drive_vendor(self):
+        """Return drive vendor."""
+        return self._P.DriveVendor
+
+    @property
+    def drive_model(self):
+        """Return drive model."""
+        return self._P.DriveModel
+
     # Drive methods
     def eject(self, unmount=False):
         """Eject media from the device."""
@@ -266,6 +256,16 @@ class Device(object):
 
     symbolic_icon_name = icon_name
 
+    @property
+    def symlinks(self):
+        """Known symlinks of the block device."""
+        return list(filter(None, [
+            self._P.DeviceFile,
+            self._P.DeviceFilePresentation,
+            self._P.DeviceFileById,
+            self._P.DeviceFileByPath,
+        ]))
+
     # ----------------------------------------
     # Partition
     # ----------------------------------------
@@ -278,6 +278,11 @@ class Device(object):
             return None
         return self._daemon[self._P.PartitionSlave]
 
+    @property
+    def partition_uuid(self):
+        """Get the partition UUID."""
+        return self._P.PartitionUuid
+
     # ----------------------------------------
     # Filesystem
     # ----------------------------------------
@@ -356,21 +361,27 @@ class Device(object):
         """Get the file backing the loop device."""
         return self._P.LinuxLoopFilename
 
+    @property
+    def setup_by_uid(self):
+        """[NOT IN UDISKS1] Get the ID of the user who set up the loop device."""
+        return None
+
+    @property
+    def autoclear(self):
+        """[NOT IN UDISKS1] If True the loop device will be deleted after unmounting."""
+        return None
+
+    def delete(self, *args, **kwargs):
+        raise NotImplementedError("No support for manipulating loop devices in UDisks1!")
+
+    set_autoclear = delete
+
+    loop_support = False
+
     # ----------------------------------------
     # derived properties
     # ----------------------------------------
 
-    @property
-    def in_use(self):
-        """Check whether this device is in use, i.e. mounted or unlocked."""
-        if self.is_mounted or self.is_unlocked:
-            return True
-        if self.is_partition_table:
-            for device in self._daemon:
-                if device.partition_slave == self and device.in_use:
-                    return True
-        return False
-
     @property
     def parent_object_path(self):
         if self.is_partition:
@@ -380,10 +391,6 @@ class Device(object):
         else:
             return '/'
 
-    @property
-    def ui_label(self):
-        return self.id_label or self.id_uuid or self.device_presentation
-
 
 def _keep_async_event_order(func):
     """
@@ -453,6 +460,8 @@ class Daemon(Emitter):
         """Iterate over all devices."""
         return (self[object_path] for object_path in self.paths())
 
+    keyfile_support = False
+
     def __getitem__(self, object_path):
         return self.get(object_path)
 
@@ -472,7 +481,7 @@ class Daemon(Emitter):
                 return device
         raise ValueError(_('no device found owning "{0}"', path))
 
-    def __init__(self, proxy):
+    def __init__(self, proxy, version):
         """
         Create a Daemon object and start listening to DBus events.
 
@@ -492,8 +501,13 @@ class Daemon(Emitter):
                        'job_failed']
         super(Daemon, self).__init__(event_names)
 
-        self._proxy = proxy
         self._log = logging.getLogger(__name__)
+        self._log.debug(_('Daemon version: {0}', version))
+
+        self.version = version
+        self.version_info = tuple(map(int, version.split('.')))
+
+        self._proxy = proxy
 
         self._jobs = {}
         self._devices = {}
@@ -512,10 +526,27 @@ class Daemon(Emitter):
     @classmethod
     @Coroutine.from_generator_function
     def create(cls):
-        proxy = yield connect_service(cls)
-        udisks = cls(proxy)
-        yield udisks._sync()
-        yield Return(udisks)
+        service = (cls.BusName, cls.ObjectPath, cls.Interface)
+        proxy = yield connect_service(*service)
+        version = yield cls.get_version()
+        daemon = cls(proxy, version)
+        yield daemon._sync()
+        yield Return(daemon)
+
+    @classmethod
+    @Coroutine.from_generator_function
+    def get_version(cls):
+        service = (cls.BusName, cls.ObjectPath,
+                   'org.freedesktop.DBus.Properties')
+        manager = yield connect_service(*service)
+        version = yield DBusCall(manager._proxy, 'Get', '(ss)', (
+            cls.Interface, 'DaemonVersion'))
+        yield Return(version)
+
+    def loop_setup(self, fd, options):
+        raise NotImplementedError("UDisks1 does not support LoopSetup!")
+
+    loop_support = False
 
     # Sniffer overrides
     def paths(self):
